Installation
============

elpigraph-python requires Python 3.6 or later.

PyPI
^^^^

Install elpigraph-python from PyPI_ using::

    pip install elpigraph-python

Development Version
^^^^^^^^^^^^^^^^^^^

To work with the latest development version, install from GitHub_ using::

    pip install git+https://github.com/j-bac/elpigraph-python

or::

    git clone https://github.com/j-bac/elpigraph-python
    pip install -e elpigraph-python

Dependencies
^^^^^^^^^^^^
- `numba <https://numba.pydata.org/>`_
- `numpy <https://docs.scipy.org/>`_
- `scipy <https://docs.scipy.org/>`_
- `scikit-learn <https://scikit-learn.org/>`_
- `matplotlib <https://matplotlib.org/>`_
- `pandas <https://pandas.pydata.org/>`_

If you run into issues, do not hesitate to approach us or raise a `GitHub issue`_.

.. _PyPI: https://pypi.org/project/elpigraph-python
.. _Github: https://github.com/j-bac/elpigraph-python
.. _`Github issue`: https://github.com/j-bac/elpigraph-python/issues/new/choose